@@ -7,12 +7,15 @@ import random
 import yaml
 
 
-class Rumor(object):
+class Rumor:
     __slots__ = ['attributes']
 
     def __init__(self, **attributes):
         self.attributes = attributes
 
+    def __str__(self):
+        return str(random.randrange(10000))
+
     def __getattr__(self, item):
         try:
             return self.attributes[item]
